# TOPSIS Package in Python
Added by: Jashan


# Concept of TOPSIS
TOPSIS is an acronym that stands for Technique of Order Preference Similarity to the Ideal Solution and is a pretty straightforward MCDA method. As the name implies, the method is based on finding an ideal and an anti-ideal solution and comparing the distance of each one of the alternatives to those.



The rankings are displayed in the form of a table using a package 'tabulate', with the 1st rank offering us the best decision, and last rank offering the worst decision making, according to TOPSIS method.

# Example
Input data 
![image](https://user-images.githubusercontent.com/72308753/213905044-a9e1eb53-f7b6-4f86-ab95-b20369625503.png)

After appling topsis 
![image](https://user-images.githubusercontent.com/72308753/213905055-f87f1a70-0e88-40ca-b5e0-9e4380d93468.png)
